@@ -1,4 +1,4 @@
-use crate::{os_input_output::ServerOsApi, panes::PaneId, tab::Pane};
+use crate::{panes::PaneId, tab::Pane};
 use cassowary::{
     strength::{REQUIRED, STRONG},
     Expression, Solver, Variable,
@@ -12,7 +12,6 @@ use zellij_utils::{
 
 pub struct PaneResizer<'a> {
     panes: HashMap<&'a PaneId, &'a mut Box<dyn Pane>>,
-    os_api: &'a mut Box<dyn ServerOsApi>,
     vars: HashMap<PaneId, Variable>,
     solver: Solver,
 }
@@ -31,18 +30,14 @@ struct Span {
 type Grid = Vec<Vec<Span>>;
 
 impl<'a> PaneResizer<'a> {
-    pub fn new(
-        panes: impl Iterator<Item = (&'a PaneId, &'a mut Box<dyn Pane>)>,
-        os_api: &'a mut Box<dyn ServerOsApi>,
-    ) -> Self {
-        let panes: HashMap<_, _> = panes.collect();
+    pub fn new(panes: impl IntoIterator<Item = (&'a PaneId, &'a mut Box<dyn Pane>)>) -> Self {
+        let panes: HashMap<_, _> = panes.into_iter().collect();
         let mut vars = HashMap::new();
         for &&k in panes.keys() {
             vars.insert(k, Variable::new());
         }
         PaneResizer {
             panes,
-            os_api,
             vars,
             solver: Solver::new(),
         }
@@ -89,7 +84,7 @@ impl<'a> PaneResizer<'a> {
 
         // Round f64 pane sizes to usize without gaps or overlap
         let mut finalised = Vec::new();
-        for spans in grid.iter_mut() {
+        for spans in &mut grid {
             let rounded_size: isize = spans.iter().map(|s| rounded_sizes[&s.size_var]).sum();
             let mut error = space as isize - rounded_size;
             let mut flex_spans: Vec<_> = spans
@@ -110,9 +105,9 @@ impl<'a> PaneResizer<'a> {
         }
 
         // Update span positions based on their rounded sizes
-        for spans in grid.iter_mut() {
+        for spans in &mut grid {
             let mut offset = 0;
-            for span in spans.iter_mut() {
+            for span in spans {
                 span.pos = offset;
                 let sz = rounded_sizes[&span.size_var];
                 if sz < 1 {
@@ -146,13 +141,6 @@ impl<'a> PaneResizer<'a> {
             } else {
                 pane.set_geom(new_geom);
             }
-            if let PaneId::Terminal(pid) = pane.pid() {
-                self.os_api.set_terminal_size_using_fd(
-                    pid,
-                    pane.get_content_columns() as u16,
-                    pane.get_content_rows() as u16,
-                );
-            }
         }
     }
 
